@@ -72,7 +72,7 @@ PpdFile *SetCommonOptions(int num_options, cups_option_t * options,
 			  int change_size, float *PageWidth, float *PageLength,
 			  float *PageTop, float *PageBottom, float *PageLeft,
 			  float *PageRight, int *LanguageLevel,
-			  unsigned int *flags, char *ppdfilename);
+			  unsigned int *flags, const char *ppdfilename);
 int cupsTempFile(char *filename, int len);
 
 inline unsigned int get_slowcollate(unsigned int flags);
@@ -293,7 +293,7 @@ int main(int argc, char *argv[])
   float PageTop = 756.0f;	// Top margin 
   float PageWidth = 612.0f;	// Total page width 
   float PageLength = 792.0f;	// Total page length 
-  char *ppdfilename = getenv("PPD");
+  const char *ppdfilename = getenv("PPD");
   GSList *list;			// List enumeration variable.
 
   unsigned int flags;
@@ -382,7 +382,7 @@ int main(int argc, char *argv[])
 	NUp = atoi(optarg);
 	break;
       case 'D':
-	num_options = cupsAddOption("Duplex", "Tumble", num_options, &options);
+	num_options = cupsAddOption("Duplex", "DuplexTumble", num_options, &options);
 	break;
       case 'V':
 	printf("%s Version: %s\n", g_basename(argv[0]), VERSION);
@@ -390,11 +390,11 @@ int main(int argc, char *argv[])
       case 'd':
 	if (optarg == 0 || !strcasecmp("NoTumble", optarg)) {
 	  num_options =
-	    cupsAddOption("Duplex", "NoTumble", num_options, &options);
+	    cupsAddOption("Duplex", "DuplexNoTumble", num_options, &options);
 	  break;
 	} else if (!strcasecmp("Tumble", optarg)) {
 	  num_options =
-	    cupsAddOption("Duplex", "Tumble", num_options, &options);
+	    cupsAddOption("Duplex", "DuplexTumble", num_options, &options);
 	  break;
 	}
 	/* intentionally falls through because they are trying to set tumble to 
@@ -1096,7 +1096,7 @@ PpdFile *SetCommonOptions(int num_options, cups_option_t * options,
 			  int change_size, float *PageWidth, float *PageLength,
 			  float *PageTop, float *PageBottom, float *PageLeft,
 			  float *PageRight, int *LanguageLevel,
-			  unsigned int *flags, char *ppdfilename)
+			  unsigned int *flags, const char *ppdfilename)
 {
   float temp;			// Swapping variable 
   PpdFile *ppd;			// PPD file 
